@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright @ 2015 HP Development Company, L.P.
@@ -23,7 +23,6 @@ import os
 import getpass
 import time
 import string
-import platform
 
 from . import utils, tui
 from .g import *
@@ -142,7 +141,8 @@ class Password(object):
 
     def __readAuthType(self):
         # TBD: Getting distro name should get distro class
-        distro_name = get_distro_name().lower()
+        # added replace() to remove the spaces in distro_name
+        distro_name = get_distro_name().lower().replace(" ","")
 
         self.__authType = user_conf.get('authentication', 'su_sudo', '')
         if self.__authType != "su" and self.__authType != "sudo":
