@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2001-2018 HP Development Company, L.P.
@@ -585,7 +585,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_pcard = 'hp-unload -d %DEVICE_URI%'
         else:
-            self.cmd_pcard = '/usr/local/bin/python3.7 %HOME%/unload.py -d %DEVICE_URI%'
+            self.cmd_pcard = '/usr/local/bin/python3.8 %HOME%/unload.py -d %DEVICE_URI%'
 
         # Copy
         path = which('hp-makecopies')
@@ -593,7 +593,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
         else:
-            self.cmd_copy = '/usr/local/bin/python3.7 %HOME%/makecopies.py -d %DEVICE_URI%'
+            self.cmd_copy = '/usr/local/bin/python3.8 %HOME%/makecopies.py -d %DEVICE_URI%'
 
         # Fax
         path = which('hp-sendfax')
@@ -601,7 +601,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fax = 'hp-sendfax -d %FAX_URI%'
         else:
-            self.cmd_fax = '/usr/local/bin/python3.7 %HOME%/sendfax.py -d %FAX_URI%'
+            self.cmd_fax = '/usr/local/bin/python3.8 %HOME%/sendfax.py -d %FAX_URI%'
 
         # Fax Address Book
         path = which('hp-fab')
@@ -609,7 +609,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fab = 'hp-fab'
         else:
-            self.cmd_fab = '/usr/local/bin/python3.7 %HOME%/fab.py'
+            self.cmd_fab = '/usr/local/bin/python3.8 %HOME%/fab.py'
 
     def load(self):
         self.loadDefaults()
@@ -2055,7 +2055,7 @@ def download_from_network(weburl, outputFile = None, useURLLIB=False):
     retValue = -1
 
     if platform.system() == "Linux":
-        if weburl is "" or weburl is None:
+        if weburl == "" or weburl == None:
             log.error("URL is empty")
             return retValue, ""
 
@@ -2095,8 +2095,6 @@ def download_from_network(weburl, outputFile = None, useURLLIB=False):
             return retValue, ""
 
         return 0, outputFile
-    else:
-        return retValue, ""
 
 
 
